'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = _interopDefault(require('react'));
var VisuallyHidden = _interopDefault(require('@reach/visually-hidden'));
var __chunk_1 = require('./chunk-0a76e4bb.js');
var tabs = require('@reach/tabs');

function useLoading() {
    const [isLoading, setState] = React.useState(false);
    const mount = React.useRef(false);
    React.useEffect(() => {
        mount.current = true;
        return () => void (mount.current = false);
    }, []);
    function load(aPromise) {
        setState(true);
        return aPromise.finally(() => mount.current && setState(false));
    }
    return [isLoading, load];
}

function Login() {
    const { loginUser } = __chunk_1.useIdentityContext();
    const formRef = React.useRef(null);
    const [msg, setMsg] = React.useState("");
    const [isLoading, load] = useLoading();
    // const signup = () => {
    //   if (!formRef.current) return
    //   const email = formRef.current.email.value
    //   const password = formRef.current.password.value
    //   const data = { signupSource: "react-netlify-identity-widget" }
    //   load(signupUser(email, password, data))
    //     .then(user => {
    //       console.log("Success! Signed up", user)
    //       // navigate("/dashboard")
    //     })
    //     .catch(err => void console.error(err) || setMsg("Error: " + err.message))
    // }
    return (React.createElement("form", { ref: formRef, className: "form", onSubmit: (e) => {
            e.preventDefault();
            const target = e.target;
            const email = target.email.value;
            const password = target.password.value;
            load(loginUser(email, password, true))
                .then(user => {
                console.log("Success! Logged in", user);
                // navigate("/dashboard")
            })
                .catch(err => void console.error(err) || setMsg("Error: " + err.message));
        } },
        React.createElement("div", { className: "formGroup", key: "email" },
            React.createElement("label", null,
                React.createElement(VisuallyHidden, null, "Enter your email"),
                React.createElement("input", { className: "formControl", type: "email", name: "email", placeholder: "Email", autoCapitalize: "off", required: true }),
                React.createElement("div", { className: "inputFieldIcon inputFieldEmail" }))),
        React.createElement("div", { className: "formGroup", key: "password" },
            React.createElement("label", null,
                React.createElement(VisuallyHidden, null, "Enter your password"),
                React.createElement("input", { className: "formControl", type: "password", name: "password", placeholder: "Password", required: true }),
                React.createElement("div", { className: "inputFieldIcon inputFieldPassword" }))),
        React.createElement("div", null,
            React.createElement("button", { type: "submit", className: isLoading ? "btn saving" : "btn" }, "Log in"),
            msg && React.createElement("pre", { style: { background: "salmon", padding: 10 } }, msg)),
        React.createElement("button", { type: "button", className: "btnLink forgotPasswordLink" }, "Forgot password?")));
}

function Logout() {
    const identity = __chunk_1.useIdentityContext();
    const name = (identity && identity.user && identity.user.user_metadata && identity.user.user_metadata.full_name) || "NoName";
    const [isLoading, load] = useLoading();
    const logout = () => load(identity.logoutUser());
    return (React.createElement(React.Fragment, null,
        React.createElement("div", { className: "header" },
            React.createElement("button", { className: "btn btnHeader active" }, "Logged in")),
        React.createElement("form", { className: "form " },
            React.createElement("p", { className: "infoText" },
                "Logged in as ",
                React.createElement("br", null),
                React.createElement("span", { className: "infoTextEmail" }, name)),
            React.createElement("button", { type: "submit", className: isLoading ? "btn saving" : "btn", onClick: logout }, "Log out"))));
}

function Signup() {
    const { signupUser } = __chunk_1.useIdentityContext();
    const formRef = React.useRef(null);
    const [msg, setMsg] = React.useState("");
    const [isLoading, load] = useLoading();
    const signup = () => {
        if (!formRef.current)
            return;
        const full_name = formRef.current.username.value;
        const email = formRef.current.email.value;
        const password = formRef.current.password.value;
        const data = { signupSource: "react-netlify-identity-widget", full_name };
        load(signupUser(email, password, data))
            .then(user => {
            console.log("Success! Signed up", user);
            // navigate("/dashboard")
        })
            .catch(err => void console.error(err) || setMsg("Error: " + err.message));
    };
    return (React.createElement("form", { ref: formRef, className: "form", onSubmit: (e) => {
            e.preventDefault();
            signup();
        } },
        React.createElement("div", { className: "formGroup", key: "username" },
            React.createElement("label", null,
                React.createElement(VisuallyHidden, null, "Enter your name"),
                React.createElement("input", { id: "username", className: "formControl", type: "name", name: "username", placeholder: "Name", autoCapitalize: "off", required: true }),
                React.createElement("div", { className: "inputFieldIcon inputFieldName" }))),
        React.createElement("div", { className: "formGroup", key: "email" },
            React.createElement("label", null,
                React.createElement(VisuallyHidden, null, "Enter your email"),
                React.createElement("input", { className: "formControl", type: "email", name: "email", placeholder: "Email", autoCapitalize: "off", required: true }),
                React.createElement("div", { className: "inputFieldIcon inputFieldEmail" }))),
        React.createElement("div", { className: "formGroup", key: "password" },
            React.createElement("label", null,
                React.createElement(VisuallyHidden, null, "Enter your password"),
                React.createElement("input", { className: "formControl", type: "password", name: "password", placeholder: "Password", required: true }),
                React.createElement("div", { className: "inputFieldIcon inputFieldPassword" }))),
        React.createElement("div", null,
            React.createElement("button", { type: "submit", className: isLoading ? "btn saving" : "btn" }, "Sign Up"),
            msg && React.createElement("pre", { style: { background: "salmon", padding: 10 } }, msg))));
}

function Providers() {
    const setting = React.useContext(__chunk_1.SettingContext);
    const hasProviders = setting &&
        setting.external &&
        Object.entries(setting.external).some(([k, v]) => ["github", "gitlab", "bitbucket", "google"].includes(k) && v);
    if (!hasProviders)
        return null;
    return (React.createElement("div", { className: "providersGroup" },
        React.createElement("hr", { className: "hr" }),
        React.createElement(ProviderButton, { setting: setting, provider: "Google" }),
        React.createElement(ProviderButton, { setting: setting, provider: "GitHub" }),
        React.createElement(ProviderButton, { setting: setting, provider: "GitLab" }),
        React.createElement(ProviderButton, { setting: setting, provider: "Bitbucket" })));
}
function ProviderButton({ setting, provider }) {
    if (!setting)
        return null;
    const ext = setting.external;
    if (!ext[provider.toLowerCase()])
        return null;
    const { loginProvider } = __chunk_1.useIdentityContext();
    const click = () => loginProvider(provider.toLowerCase());
    return (React.createElement("button", { onClick: click, className: `provider${provider} btn btnProvider` },
        "Continue with ",
        provider));
}

function LoggedOutScreen() {
    return (React.createElement("div", null,
        React.createElement(tabs.Tabs, { defaultIndex: 0 },
            React.createElement(tabs.TabList, { className: "header" },
                React.createElement(tabs.Tab, { className: "btn btnHeader " }, "Login"),
                React.createElement(tabs.Tab, { className: "btn btnHeader " }, "Sign Up")),
            React.createElement(tabs.TabPanels, null,
                React.createElement(tabs.TabPanel, null,
                    React.createElement(Login, null)),
                React.createElement(tabs.TabPanel, null,
                    React.createElement(Signup, null)))),
        React.createElement(Providers, null)));
}
function LoggedInScreen() {
    return React.createElement(Logout, null);
}
function Gate({}) {
    const identity = __chunk_1.useIdentityContext();
    const isLoggedIn = Boolean(identity && identity.user);
    return isLoggedIn ? React.createElement(LoggedInScreen, null) : React.createElement(LoggedOutScreen, null);
}
function Widget({ onCloseDialog }) {
    return React.createElement(Gate, { onCloseDialog: onCloseDialog });
}

exports.default = Widget;
//# sourceMappingURL=chunk-6c25e11d.js.map
