'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = _interopDefault(require('react'));
var dialog = require('@reach/dialog');
var VisuallyHidden = _interopDefault(require('@reach/visually-hidden'));
var __chunk_1 = require('./chunk-0a76e4bb.js');
var reactNetlifyIdentity = require('react-netlify-identity');

class ErrorBoundary extends React.Component {
    constructor(props) {
        super(props);
        this.state = { hasError: false };
    }
    static getDerivedStateFromError() {
        // Update state so the next render will show the fallback UI.
        return { hasError: true };
    }
    render() {
        if (this.state.hasError) {
            // You can render any custom fallback UI
            return React.createElement("h1", null, "Something went loading the widget.");
        }
        return this.props.children;
    }
}

const Widget = React.lazy(() => Promise.resolve(require('./chunk-6c25e11d.js')));
const IdentityContextProvider = __chunk_1.IdentityContextProvider;
const useNetlifyIdentity = reactNetlifyIdentity.useNetlifyIdentity;
const IdentityContext = __chunk_1.IdentityContext;
const useIdentityContext = __chunk_1.useIdentityContext;
function IdentityModal({ showDialog, onCloseDialog }) {
    const { settings } = useIdentityContext();
    const [setting, setSetting] = React.useState(null);
    React.useEffect(() => {
        settings().then(x => setSetting(x));
    }, [settings]);
    return (React.createElement(__chunk_1.SettingContext.Provider, { value: setting },
        React.createElement(dialog.Dialog, { isOpen: showDialog, onDismiss: () => void console.log("hi") || onCloseDialog(), style: {
                border: "solid 5px hsla(0, 0%, 0%, 0.5)",
                borderRadius: "10px",
                position: "relative",
                maxWidth: 400
            } },
            React.createElement("button", { className: "btn btnClose", onClick: onCloseDialog },
                React.createElement(VisuallyHidden, null, "Close")),
            React.createElement(__chunk_1.FormStateContextProvider, null,
                React.createElement(ErrorBoundary, null,
                    React.createElement(React.Suspense, { fallback: React.createElement("div", null, "Loading...") },
                        React.createElement(Widget, { onCloseDialog: onCloseDialog })))))));
}

exports.IdentityContext = IdentityContext;
exports.IdentityContextProvider = IdentityContextProvider;
exports.IdentityModal = IdentityModal;
exports.useIdentityContext = useIdentityContext;
exports.useNetlifyIdentity = useNetlifyIdentity;
//# sourceMappingURL=index.js.map
